@@ -4,10 +4,11 @@ package Module::Release::SVN;
 use strict;
 use warnings;
 use base qw(Exporter);
+use vars qw($VERSION);
 
 our @EXPORT = qw(check_cvs cvs_tag make_cvs_tag);
 
-our $VERSION = '0.10_02';
+$VERSION = '2.00_05';
 
 =head1 NAME
 
@@ -222,9 +223,9 @@ L<Module::Release>
 
 =head1 SOURCE AVAILABILITY
 
-So far this is in a private git repository. It's only private because I'm
-lazy. I can send it to you if you like, and I promise to set up something
-public Real Soon Now.
+This source is in Github:
+
+	git://github.com/briandfoy/module-release.git
 
 =head1 AUTHOR
 
